--[[
MobileVault_Sharing - Optional module to enable sharing and syncing of the guild bank
using LibGuildBankComm-1.0
Author: Michael Joseph Murray aka Lyte of Lothar(US)
Please see license.txt for details.
$Revision: 194 $
$Date: 2011-05-27 20:30:05 +0000 (Fri, 27 May 2011) $
Project Version: r203
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2011 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

local MGV = LibStub("AceAddon-3.0"):GetAddon("MobileVault")
local LGBC = LibStub("LibGuildBankComm-1.0")

local Sharing = MGV:NewModule("MobileVault_Sharing")

local function canViewTab(page)
	local _, _, view = GetGuildBankTabInfo(page)
	return view == 1 and true or false
end

function Sharing:OnEnable()
	--expects LibGuildBankComm v42b or greater
	LGBC.RegisterCallback(self, "GuildBankComm_PageUpdate", "OnPageSync")
	LGBC.RegisterCallback(self, "GuildBankComm_FundsUpdate", "OnMoneySync")
	LGBC.RegisterCallback(self, "GuildBankComm_TabsUpdate", "OnTabSync")
end

function Sharing:OnPageSync(event, sender, page, guildName)
	--[===[@debug@
	print("Page Sync", page, "from", sender, "for guild", guildName)
	--@end-debug@]===]
	
	--now repopulate our image with the more recent data from the library
	for slot, link, stack in LGBC:IteratePage(page) do
		MGV.guilds[guildName][page].links[slot] = link
		MGV.guilds[guildName][page].stacks[slot] = stack
	end
	
	--finally get the timestamp for this page
	MGV.guilds[guildName][page].lastUpdate = LGBC:GetPageTimestamp(page)
end

function Sharing:OnMoneySync(event, sender, newFunds, guildName)
	--[===[@debug@
	print("Money Sync from", sender, "for guild", guildName)
	--@end-debug@]===]
	
	MGV.guilds[guildName].guildfunds = newFunds
end

function Sharing:OnTabSync(event, sender, numTabs, guildName)
	--[===[@debug@
	print("Tab Sync from", sender, "for guild", guildName)
	--@end-debug@]===]
	
	MGV.guilds[guildName].numtabs = numTabs
	
	for page = 1, numTabs do
		local name, icon = LGBC:GetTabInfo(page)
		MGV.guilds[guildName][page].texture = icon
		MGV.guilds[guildName][page].name = name
		MGV.guilds[guildName][page] = canViewTab(page)
	end
end
